@@ -15,6 +15,7 @@ rm -rf julius*
 tar xzvf $1
 ln -s julius-* julius
 rm -rf include/sent include/julius
+rm -rf man
 mv aaa julius-simple
 
 # update binaries
@@ -24,7 +25,11 @@ mv build/bin/* ../bin
 mv build/lib/* ../lib
 mv build/include/* ../include
 mv julius-simple/julius-simple.c ../julius-simple
-cd ..
+# normalize libsent/libjulius directory for julius-simple
+perl ./support/setprefix.pl .. bin/libsent-config > tmp
+mv tmp bin/libsent-config
+perl ./support/setprefix.pl .. bin/libjulius-config > tmp
+mv tmp bin/libjulius-config
 
 # copy the documents
 cp -p julius/00readme.txt 00readme-julius.txt
@@ -32,18 +37,10 @@ cp -p julius/00readme-ja.txt 00readme-julius-ja.txt
 cp -p julius/LICENSE.txt .
 cp -p julius/Release* .
 cp -p julius/Sample*jconf* .
-cp -p julius/gramtools/00readme.txt doc/gramtools.txt
-cp -p julius/gramtools/00readme-ja.txt doc/gramtools-ja.txt
 
 # copy manuals
-find julius/ -name "*.man" -exec ./support/cpman.sh {} \;
-find julius/ -name "*.man.ja" -exec ./support/cpmanja.sh {} \;
-mv doc/man/*.1 doc/man/man1
-mv doc/man/man1/jconf.1 doc/man/man5/jconf.5
-mv doc/man.ja/*.1 doc/man.ja/man1
-mv doc/man.ja/man1/jconf.1 doc/man.ja/man5/jconf.5
-qkc -m doc/txt/*
-qkc -s -m doc/txt.ja/*
+cp -pr julius/man .
+rm -f man/Makefile.in
 
 # finished
 rm -f julius
